@@ -53,7 +53,7 @@ CDesktop::CDesktop()
     QCoreApplication::instance()->setApplicationName("FM Rds Notify");
     QCoreApplication::instance()->setOrganizationName("FM Rds Notify");
 
-
+#ifndef SIM
     // Get required atoms
     Atom winTypeAtom = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false);
     Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
@@ -74,7 +74,7 @@ CDesktop::CDesktop()
     int settings = 0;
     XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
 		    PropModeReplace, (unsigned char*)&settings, 1);
-
+#endif
     QSettings cfg;
     if (!cfg.value("main/theme","").toString().isEmpty()) {
         if (QFile::exists(QDir::homePath() + QLatin1String("/.fmrdsnotify/")+cfg.value("main/theme","").toString()+QLatin1String(".svg")))
@@ -161,6 +161,7 @@ void CDesktop::paintEvent(QPaintEvent *e)
 }
 
 //Filter show setting requests
+#ifndef SIM
 bool QWidget::x11Event ( XEvent * event )
 {
   static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
@@ -175,6 +176,7 @@ bool QWidget::x11Event ( XEvent * event )
   }
   return false;
 }
+#endif
 
 void CDesktop::resizeEvent(QResizeEvent *e)
 {
