@@ -20,16 +20,6 @@ CSms::CSms(QObject * parent)
     timeout = cfg.value("display/sms/timeout", timeout).toInt();
     state = cfg.value("main/sms", state).toBool();
 
-    messageManager = new QMessageManager(this);
-    connect(messageManager, SIGNAL(messageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)), this, SLOT(slotMessageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)));
-
-    // - SMS filter
-    // - InboxFolder filter
-    m_notifFilterSet.insert(messageManager->registerNotificationFilter(
-        QMessageFilter::byType(QMessage::Sms) &
-        QMessageFilter::byStandardFolder(QMessage::InboxFolder)));
-
-
     bConnect = false;
 }
 
@@ -63,6 +53,17 @@ int CSms::getTimeout()
 
 void CSms::setEnable(bool value)
 {
+    if (value) {
+        messageManager = new QMessageManager(this);
+        connect(messageManager, SIGNAL(messageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)), this, SLOT(slotMessageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)));
+        // - SMS filter
+        // - InboxFolder filter
+        m_notifFilterSet.insert(messageManager->registerNotificationFilter(
+            QMessageFilter::byType(QMessage::Sms) &
+            QMessageFilter::byStandardFolder(QMessage::InboxFolder)));
+    } else {
+        delete messageManager;
+    }
     state = value;
     qDebug() << "Connected is " << value;
 }
@@ -89,7 +90,7 @@ void CSms::setConnect(int value)
     if (value)
         setEnable(state);
     else {
-        //QDBusConnection::sessionBus().disconnect( 0, SMS_CSD_PATH, "org.freedesktop.Telepathy.Connection.Interface.Requests",  "NewChannels", this, SLOT(slotNotify(QList<QVariant>)));
+        delete messageManager;
     }
     bConnect = value;
 }
