@@ -7,9 +7,10 @@
 #define RTCOM_CSD_IF   "com.nokia.csd.Call"
 #define RTCOM_CSD_INST_IF   "com.nokia.csd.Call.Instance"
 // Sms
-#define SMS_CSD_PATH  "/org/freedesktop/Telepathy/Connection/ring/tel/ring/text10"
-#define SMS_CSD_IF   "org.freedesktop.Telepathy.Channel.Interface.Messages"
-#define SMS_CSD_INST_IF   "org.freedesktop.Telepathy.Channel.Interface.Messages"
+#define SMS_CSD_PATH  "/org/freedesktop/Telepathy/Connection/ring/tel/ring"
+#define SMS_CSD_IF_CON   "org.freedesktop.Telepathy.Connection"
+#define SMS_CSD_IF_MSG   "org.freedesktop.Telepathy.Channel.Interface.Messages"
+#define SMS_CSD_IF_TEXT   "org.freedesktop.Telepathy.Channel.Type.Text"
 
 #define FMTX_PATH "/com/nokia/fmtx/default"
 #define FMTX_IF "com.nokia.policy"
